### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

#### [v0.1.2](https://github.com/RhetTbull/CGMetadata/compare/v0.1.1...v0.1.2)

> 7 November 2023

- Added CLI [`0fecc69`](https://github.com/RhetTbull/CGMetadata/commit/0fecc69f41d57fc06eea73923e2a4dd4ac089262)
- Added CLI tests [`1e276df`](https://github.com/RhetTbull/CGMetadata/commit/1e276dffbdd42435972a96ab4b3b71979f42ea2f)
- Updated docs [`4444cec`](https://github.com/RhetTbull/CGMetadata/commit/4444cecfde158bb6a71c8be8a091ec357d867063)

#### [v0.1.1](https://github.com/RhetTbull/CGMetadata/compare/v0.1.0...v0.1.1)

> 5 November 2023

- Exclude site/ tests/ in publish [`2cea9e6`](https://github.com/RhetTbull/CGMetadata/commit/2cea9e6687f3f0649321ff2bec26829ceab6a813)
- Version bump [`94a60df`](https://github.com/RhetTbull/CGMetadata/commit/94a60df581bd43956eae7b04e3336b8b0e962cf9)
- Version bump [`2231734`](https://github.com/RhetTbull/CGMetadata/commit/223173423ee945aabf38240d8d2519e24c907149)

#### v0.1.0

> 5 November 2023

- First commit [`0b906fa`](https://github.com/RhetTbull/CGMetadata/commit/0b906fa8f3fccc09cb9e27867f593e94a6eb17e1)
- Added tests [`b6a3ed0`](https://github.com/RhetTbull/CGMetadata/commit/b6a3ed0e797b435964d93cb02581ead75e52b94b)
- Added xmp() functions [`4ff2e9d`](https://github.com/RhetTbull/CGMetadata/commit/4ff2e9d6374895e3dd3223161996deb4993ac702)
